@@ -56,12 +56,12 @@ MOD_AUTH_STRUCT anon_auth_struct = {
  * opaque data.
  */
 int _gnutls_generate_key(GNUTLS_KEY key) {
-        gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &key->key.size, key->KEY);
-	key->key.data = secure_malloc( key->key.size);
+        _gnutls_mpi_print( NULL, &key->key.size, key->KEY);
+	key->key.data = gnutls_secure_malloc( key->key.size);
 	if ( key->key.data==NULL) {
 		return GNUTLS_E_MEMORY_ERROR;
 	}
-	gcry_mpi_print(GCRYMPI_FMT_USG, key->key.data, &key->key.size, key->KEY);
+	_gnutls_mpi_print( key->key.data, &key->key.size, key->KEY);
 	return 0;
 }
 
@@ -111,9 +111,9 @@ int gen_anon_server_kx( GNUTLS_STATE state, opaque** data) {
 	}
 	
 	state->gnutls_key->dh_secret = x;
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &n_g, g);
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &n_p, p);
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &n_X, X);
+	_gnutls_mpi_print( NULL, &n_g, g);
+	_gnutls_mpi_print( NULL, &n_p, p);
+	_gnutls_mpi_print( NULL, &n_X, X);
 	(*data) = gnutls_malloc(n_g + n_p + n_X + 6);
 	if (*data==NULL) {
 		_gnutls_mpi_release( &X);
@@ -122,19 +122,19 @@ int gen_anon_server_kx( GNUTLS_STATE state, opaque** data) {
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 	data_p = &(*data)[0];
-	gcry_mpi_print(GCRYMPI_FMT_USG, &data_p[2], &n_p, p);
+	_gnutls_mpi_print( &data_p[2], &n_p, p);
 	_gnutls_mpi_release(&p);
 
 	WRITEuint16( n_p, data_p);
 
 	data_g = &data_p[2 + n_p];
-	gcry_mpi_print(GCRYMPI_FMT_USG, &data_g[2], &n_g, g);
+	_gnutls_mpi_print( &data_g[2], &n_g, g);
 	_gnutls_mpi_release(&g);
 	
 	WRITEuint16( n_g, data_g);
 
 	data_X = &data_g[2 + n_g];
-	gcry_mpi_print(GCRYMPI_FMT_USG, &data_X[2], &n_X, X);
+	_gnutls_mpi_print( &data_X[2], &n_X, X);
 	_gnutls_mpi_release(&X);
 
 	WRITEuint16( n_X, data_X);
@@ -153,12 +153,12 @@ int ret;
 	if (X==NULL)
 		return GNUTLS_E_MEMORY_ERROR;
 				   
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &n_X, X);
+	_gnutls_mpi_print( NULL, &n_X, X);
 	(*data) = gnutls_malloc(n_X + 2);
 	if (*data==NULL)
 		return GNUTLS_E_MEMORY_ERROR;
 	
-	gcry_mpi_print(GCRYMPI_FMT_USG, &(*data)[2], &n_X, X);
+	_gnutls_mpi_print( &(*data)[2], &n_X, X);
 	(*data)[0] = 1;	/* extern - explicit since we do not have
 				   certificate */
 	_gnutls_mpi_release(&X);
@@ -226,19 +226,16 @@ int proc_anon_server_kx( GNUTLS_STATE state, opaque* data, int data_size) {
 	_n_g = n_g;
 	_n_p = n_p;
 
-	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y,
-			      GCRYMPI_FMT_USG, data_Y, &_n_Y) != 0 || state->gnutls_key->client_Y==NULL) {
+	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y, data_Y, &_n_Y) != 0 || state->gnutls_key->client_Y==NULL) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
 	}
 
-	if (_gnutls_mpi_scan(&state->gnutls_key->client_g,
-			      GCRYMPI_FMT_USG, data_g, &_n_g) != 0 || state->gnutls_key->client_g==NULL) {
+	if (_gnutls_mpi_scan(&state->gnutls_key->client_g, data_g, &_n_g) != 0 || state->gnutls_key->client_g==NULL) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
 	}
-	if (_gnutls_mpi_scan(&state->gnutls_key->client_p,
-				      GCRYMPI_FMT_USG, data_p, &_n_p) != 0 || state->gnutls_key->client_p==NULL) {
+	if (_gnutls_mpi_scan(&state->gnutls_key->client_p, data_p, &_n_p) != 0 || state->gnutls_key->client_p==NULL) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
 	}
@@ -273,8 +270,7 @@ int proc_anon_client_kx( GNUTLS_STATE state, opaque* data, int data_size) {
 	n_Y = READuint16( &data[0]);
 
 	_n_Y = n_Y;
-	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y,
-		      GCRYMPI_FMT_USG, &data[2], &_n_Y) !=0 || state->gnutls_key->client_Y==NULL) {
+	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y, &data[2], &_n_Y) !=0 || state->gnutls_key->client_Y==NULL) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
 	}
