@@ -119,9 +119,9 @@ static int gen_dhe_rsa_server_kx(GNUTLS_STATE state, opaque ** data)
 	}
 	state->gnutls_key->dh_secret = x;
 
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &n_g, g);
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &n_p, p);
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &n_X, X);
+	_gnutls_mpi_print( NULL, &n_g, g);
+	_gnutls_mpi_print( NULL, &n_p, p);
+	_gnutls_mpi_print( NULL, &n_X, X);
 	(*data) = gnutls_malloc(n_g + n_p + n_X + 6);
 	if (*data == NULL) {
 		_gnutls_mpi_release(&X);
@@ -131,19 +131,19 @@ static int gen_dhe_rsa_server_kx(GNUTLS_STATE state, opaque ** data)
 	}
 
 	data_p = &(*data)[0];
-	gcry_mpi_print(GCRYMPI_FMT_USG, &data_p[2], &n_p, p);
+	_gnutls_mpi_print( &data_p[2], &n_p, p);
 	_gnutls_mpi_release(&p);
 
 	WRITEuint16(n_p, data_p);
 
 	data_g = &data_p[2 + n_p];
-	gcry_mpi_print(GCRYMPI_FMT_USG, &data_g[2], &n_g, g);
+	_gnutls_mpi_print( &data_g[2], &n_g, g);
 	_gnutls_mpi_release(&g);
 
 	WRITEuint16(n_g, data_g);
 
 	data_X = &data_g[2 + n_g];
-	gcry_mpi_print(GCRYMPI_FMT_USG, &data_X[2], &n_X, X);
+	_gnutls_mpi_print( &data_X[2], &n_X, X);
 	_gnutls_mpi_release(&X);
 
 	WRITEuint16(n_X, data_X);
@@ -200,7 +200,7 @@ static int gen_dhe_rsa_client_kx(GNUTLS_STATE state, opaque ** data)
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &n_X, X);
+	_gnutls_mpi_print( NULL, &n_X, X);
 	(*data) = gnutls_malloc(n_X + 2);
 	if (*data == NULL) {
 		_gnutls_mpi_release(&x);
@@ -208,7 +208,7 @@ static int gen_dhe_rsa_client_kx(GNUTLS_STATE state, opaque ** data)
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 
-	gcry_mpi_print(GCRYMPI_FMT_USG, &(*data)[2], &n_X, X);
+	_gnutls_mpi_print( &(*data)[2], &n_X, X);
 	_gnutls_mpi_release(&X);
 
 	WRITEuint16(n_X, &(*data)[0]);
@@ -293,19 +293,16 @@ static int proc_dhe_rsa_server_kx(GNUTLS_STATE state, opaque * data,
 	_n_g = n_g;
 	_n_p = n_p;
 
-	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y,
-			     GCRYMPI_FMT_USG, data_Y, &_n_Y) != 0) {
+	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y, data_Y, &_n_Y) != 0) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
 	}
 
-	if (_gnutls_mpi_scan(&state->gnutls_key->client_g,
-			     GCRYMPI_FMT_USG, data_g, &_n_g) != 0) {
+	if (_gnutls_mpi_scan(&state->gnutls_key->client_g, data_g, &_n_g) != 0) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
 	}
-	if (_gnutls_mpi_scan(&state->gnutls_key->client_p,
-			     GCRYMPI_FMT_USG, data_p, &_n_p) != 0) {
+	if (_gnutls_mpi_scan(&state->gnutls_key->client_p, data_p, &_n_p) != 0) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
 	}
@@ -362,8 +359,7 @@ static int proc_dhe_rsa_client_kx(GNUTLS_STATE state, opaque * data,
 	n_Y = READuint16(&data[0]);
 	_n_Y = n_Y;
 
-	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y,
-			     GCRYMPI_FMT_USG, &data[2], &_n_Y)) {
+	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y, &data[2], &_n_Y)) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
 	}
