@@ -25,7 +25,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.2.90"
+#define LIBGNUTLS_VERSION "0.2.91"
 
 #include <sys/types.h>
 #include <time.h>
@@ -150,6 +150,7 @@ void gnutls_db_set_retrieve_func( GNUTLS_STATE, DB_RETR_FUNC);
 void gnutls_db_set_remove_func( GNUTLS_STATE, DB_REMOVE_FUNC);
 void gnutls_db_set_store_func( GNUTLS_STATE, DB_STORE_FUNC);
 void gnutls_db_set_ptr( GNUTLS_STATE, void* db_ptr);
+void* gnutls_db_get_ptr( GNUTLS_STATE);
 int  gnutls_db_check_entry( GNUTLS_STATE state, gnutls_datum session_entry);
 
 void gnutls_set_max_handshake_data_buffer_size( GNUTLS_STATE state, int max);
@@ -162,13 +163,6 @@ int gnutls_clear_creds( GNUTLS_STATE state);
 /* cred is a structure defined by the kx algorithm */
 int gnutls_set_cred( GNUTLS_STATE, CredType type, void* cred);
 
-/* A null terminated string containing the dnsname.
- * This will only exist if the client supports the dnsname
- * TLS extension. (draft-ietf-tls-extensions)
- */
-const void* gnutls_ext_get_name_ind( GNUTLS_STATE state, GNUTLS_NAME_IND ind);
-        int gnutls_ext_set_name_ind( GNUTLS_STATE state, GNUTLS_NAME_IND ind, const void* name);
-
 /* This will set the Common Name field in case of X509PKI
  * authentication. This will be used while verifying the
  * certificate
@@ -199,6 +193,10 @@ void gnutls_anon_free_server_sc( ANON_SERVER_CREDENTIALS sc);
 int gnutls_anon_allocate_server_sc( ANON_SERVER_CREDENTIALS *sc);
 int gnutls_anon_set_server_cred( ANON_SERVER_CREDENTIALS res, int dh_bits);
 
+void gnutls_anon_free_client_sc( ANON_SERVER_CREDENTIALS sc);
+int gnutls_anon_allocate_client_sc( ANON_SERVER_CREDENTIALS *sc);
+int gnutls_anon_set_client_cred( ANON_SERVER_CREDENTIALS res, int dh_bits);
+
 
 /* CERTFILE is an x509 certificate in PEM form.
  * KEYFILE is a pkcs-1 private key in PEM form (for RSA keys).
@@ -234,6 +232,7 @@ int gnutls_dh_generate_params( gnutls_datum* prime, gnutls_datum* generator, int
 typedef ssize_t (*GNUTLS_PULL_FUNC)(GNUTLS_SOCKET_PTR, void*, size_t);
 typedef ssize_t (*GNUTLS_PUSH_FUNC)(GNUTLS_SOCKET_PTR, const void*, size_t);
 void gnutls_transport_set_ptr(GNUTLS_STATE state, GNUTLS_SOCKET_PTR ptr);
+GNUTLS_SOCKET_PTR gnutls_transport_get_ptr(GNUTLS_STATE state);
 
 typedef void (*LOG_FUNC)( const char*);
 
@@ -337,11 +336,12 @@ int gnutls_x509pki_get_peer_certificate_status( GNUTLS_STATE);
 
 #endif /* GNUTLS_UI_H */
 
-/* error codes 
+/* Gnutls error codes. The mapping to a TLS alert is also shown in
+ * comments.
  */
 
 #define GNUTLS_E_SUCCESS 0
-#define	GNUTLS_E_MAC_FAILED  -1 /* GNUTLS_BAD_RECORD_MAC */
+#define	GNUTLS_E_MAC_FAILED  -1 /* GNUTLS_A_BAD_RECORD_MAC */
 #define	GNUTLS_E_UNKNOWN_CIPHER -2
 #define	GNUTLS_E_UNKNOWN_COMPRESSION_ALGORITHM -3
 #define	GNUTLS_E_UNKNOWN_MAC_ALGORITHM -4
@@ -355,17 +355,17 @@ int gnutls_x509pki_get_peer_certificate_status( GNUTLS_STATE);
 #define GNUTLS_E_FATAL_ALERT_RECEIVED -12
 #define GNUTLS_E_RECEIVED_BAD_MESSAGE -13
 #define GNUTLS_E_RECEIVED_MORE_DATA -14
-#define GNUTLS_E_UNEXPECTED_PACKET -15 /* GNUTLS_UNEXPECTED_MESSAGE */
+#define GNUTLS_E_UNEXPECTED_PACKET -15 /* GNUTLS_A_UNEXPECTED_MESSAGE */
 #define GNUTLS_E_WARNING_ALERT_RECEIVED -16
 #define GNUTLS_E_ERROR_IN_FINISHED_PACKET -18
 #define GNUTLS_E_UNEXPECTED_HANDSHAKE_PACKET -19
 #define GNUTLS_E_UNKNOWN_KX_ALGORITHM -20
-#define	GNUTLS_E_UNKNOWN_CIPHER_SUITE -21 /* GNUTLS_HANDSHAKE_FAILURE */
+#define	GNUTLS_E_UNKNOWN_CIPHER_SUITE -21 /* GNUTLS_A_HANDSHAKE_FAILURE */
 #define	GNUTLS_E_UNWANTED_ALGORITHM -22
 #define	GNUTLS_E_MPI_SCAN_FAILED -23
-#define GNUTLS_E_DECRYPTION_FAILED -24 /* GNUTLS_DECRYPTION_FAILED */
+#define GNUTLS_E_DECRYPTION_FAILED -24 /* GNUTLS_A_DECRYPTION_FAILED */
 #define GNUTLS_E_MEMORY_ERROR -25
-#define GNUTLS_E_DECOMPRESSION_FAILED -26 /* GNUTLS_DECOMPRESSION_FAILURE */
+#define GNUTLS_E_DECOMPRESSION_FAILED -26 /* GNUTLS_A_DECOMPRESSION_FAILURE */
 #define GNUTLS_E_COMPRESSION_FAILED -27
 #define GNUTLS_E_AGAIN -28
 #define GNUTLS_E_EXPIRED -29
@@ -375,27 +375,28 @@ int gnutls_x509pki_get_peer_certificate_status( GNUTLS_STATE);
 #define GNUTLS_E_HASH_FAILED -33
 #define GNUTLS_E_PARSING_ERROR -34
 #define	GNUTLS_E_MPI_PRINT_FAILED -35
-#define GNUTLS_E_REHANDSHAKE -37 /* GNUTLS_NO_RENEGOTIATION */
+#define GNUTLS_E_REHANDSHAKE -37 /* GNUTLS_A_NO_RENEGOTIATION */
 #define GNUTLS_E_GOT_APPLICATION_DATA -38
 #define GNUTLS_E_RECORD_LIMIT_REACHED -39
 #define GNUTLS_E_ENCRYPTION_FAILED -40
 #define GNUTLS_E_ASN1_ERROR -41
-#define GNUTLS_E_ASN1_PARSING_ERROR -42 /* GNUTLS_BAD_CERTIFICATE */
+#define GNUTLS_E_ASN1_PARSING_ERROR -42 /* GNUTLS_A_BAD_CERTIFICATE */
 #define GNUTLS_E_X509_CERTIFICATE_ERROR -43
 #define GNUTLS_E_PK_ENCRYPTION_FAILED -44
 #define GNUTLS_E_PK_DECRYPTION_FAILED -45
 #define GNUTLS_E_PK_SIGNATURE_FAILED -46
 #define GNUTLS_E_X509_UNSUPPORTED_CRITICAL_EXTENSION -47
 #define GNUTLS_E_X509_KEY_USAGE_VIOLATION -48
-#define GNUTLS_E_NO_CERTIFICATE_FOUND -49 /* GNUTLS_BAD_CERTIFICATE */
+#define GNUTLS_E_NO_CERTIFICATE_FOUND -49 /* GNUTLS_A_BAD_CERTIFICATE */
 #define GNUTLS_E_INVALID_PARAMETERS -50
 #define GNUTLS_E_INVALID_REQUEST -51
 #define GNUTLS_E_INTERRUPTED -52
 #define GNUTLS_E_PUSH_ERROR -53
 #define GNUTLS_E_PULL_ERROR -54
-#define GNUTLS_E_ILLEGAL_PARAMETER -55  /* GNUTLS_ILLEGAL_PARAMETER */
+#define GNUTLS_E_ILLEGAL_PARAMETER -55  /* GNUTLS_A_ILLEGAL_PARAMETER */
 #define GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE -56
 #define GNUTLS_E_PKCS1_WRONG_PAD -57
+#define GNUTLS_E_INTERNAL -58
 
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
 
