@@ -520,7 +520,7 @@ static int _read_rsa_params(opaque * der, int dersize, MPI * params)
 		return GNUTLS_E_ASN1_PARSING_ERROR;
 	}
 
-	if (_gnutls_mpi_scan(&params[0], GCRYMPI_FMT_USG, str, &len) != 0) {
+	if (_gnutls_mpi_scan(&params[0], str, &len) != 0) {
 		gnutls_assert();
 		asn1_delete_structure(spk);
 		return GNUTLS_E_MPI_SCAN_FAILED;
@@ -537,7 +537,7 @@ static int _read_rsa_params(opaque * der, int dersize, MPI * params)
 		return GNUTLS_E_ASN1_PARSING_ERROR;
 	}
 
-	if (_gnutls_mpi_scan(&params[1], GCRYMPI_FMT_USG, str, &len) != 0) {
+	if (_gnutls_mpi_scan(&params[1], str, &len) != 0) {
 		gnutls_assert();
 		_gnutls_mpi_release(&params[0]);
 		asn1_delete_structure(spk);
@@ -828,11 +828,17 @@ int _gnutls_cert2gnutlsCert(gnutls_cert * gCert, gnutls_datum derCert)
 
 	gCert->valid = 1;
 
+	if (gnutls_set_datum(&gCert->raw, derCert.data, derCert.size) < 0) {
+		gnutls_assert();
+		return GNUTLS_E_MEMORY_ERROR;
+	}
+
 	if (asn1_create_structure
 	    (_gnutls_get_pkix(), "PKIX1Implicit88.Certificate", &c2,
 	     "certificate2")
 	    != ASN_OK) {
 		gnutls_assert();
+		gnutls_free_datum( &gCert->raw);
 		return GNUTLS_E_ASN1_ERROR;
 	}
 
@@ -844,6 +850,7 @@ int _gnutls_cert2gnutlsCert(gnutls_cert * gCert, gnutls_datum derCert)
 #endif
 		gnutls_assert();
 		asn1_delete_structure(c2);
+		gnutls_free_datum( &gCert->raw);
 		return GNUTLS_E_ASN1_PARSING_ERROR;
 	}
 
@@ -857,6 +864,7 @@ int _gnutls_cert2gnutlsCert(gnutls_cert * gCert, gnutls_datum derCert)
 	if (result != ASN_OK) {
 		gnutls_assert();
 		asn1_delete_structure(c2);
+		gnutls_free_datum( &gCert->raw);
 		return GNUTLS_E_ASN1_PARSING_ERROR;
 	}
 
@@ -876,6 +884,7 @@ int _gnutls_cert2gnutlsCert(gnutls_cert * gCert, gnutls_datum derCert)
 		if (result != ASN_OK) {
 			gnutls_assert();
 			asn1_delete_structure(c2);
+			gnutls_free_datum( &gCert->raw);
 			return GNUTLS_E_ASN1_PARSING_ERROR;
 		}
 
@@ -883,6 +892,7 @@ int _gnutls_cert2gnutlsCert(gnutls_cert * gCert, gnutls_datum derCert)
 			gnutls_assert();
 			/* internal error. Increase the MPIs in params */
 			asn1_delete_structure(c2);
+			gnutls_free_datum( &gCert->raw);
 			return GNUTLS_E_UNKNOWN_ERROR;
 		}
 
@@ -890,6 +900,7 @@ int _gnutls_cert2gnutlsCert(gnutls_cert * gCert, gnutls_datum derCert)
 		     _read_rsa_params(str, len / 8, gCert->params)) < 0) {
 			gnutls_assert();
 			asn1_delete_structure(c2);
+			gnutls_free_datum( &gCert->raw);
 			return result;
 		}
 
@@ -915,6 +926,7 @@ int _gnutls_cert2gnutlsCert(gnutls_cert * gCert, gnutls_datum derCert)
 	if ((len % 8) != 0) {
 		gnutls_assert();
 		asn1_delete_structure(c2);
+		gnutls_free_datum( &gCert->raw);
 		return GNUTLS_E_UNIMPLEMENTED_FEATURE;
 	}
 	len /= 8;		/* convert to bytes */
@@ -933,15 +945,12 @@ int _gnutls_cert2gnutlsCert(gnutls_cert * gCert, gnutls_datum derCert)
 				  gCert)) < 0) {
 		gnutls_assert();
 		asn1_delete_structure(c2);
+		gnutls_free_datum( &gCert->raw);
 		return result;
 	}
 
 	asn1_delete_structure(c2);
 
-	if (gnutls_set_datum(&gCert->raw, derCert.data, derCert.size) < 0) {
-		gnutls_assert();
-		return GNUTLS_E_MEMORY_ERROR;
-	}
 
 	gCert->valid = 0;	/* if we got until here
 				 * the certificate is valid.
@@ -1110,6 +1119,7 @@ void gnutls_x509pki_set_client_cert_callback(GNUTLS_STATE state,
   * not attempt to choose the appropriate certificate and the caller function
   * will fail.
   *
+  * The callback function will only be called once per handshake.
   * The callback function should return the index of the certificate
   * choosen by the server (or -1 in case of an error)
   *
