@@ -38,7 +38,6 @@
 #include "auth_x509.h"
 #include "gnutls_cert.h"
 #include "gnutls_constate.h"
-#include <ext_dnsname.h>
 #include <gnutls_record.h>
 
 #ifdef HANDSHAKE_DEBUG
@@ -114,34 +113,39 @@ void _gnutls_set_client_random(GNUTLS_STATE state, uint8 * random)
 /* Calculate The SSL3 Finished message */
 #define SSL3_CLIENT_MSG "CLNT"
 #define SSL3_SERVER_MSG "SRVR"
-void *_gnutls_ssl3_finished(GNUTLS_STATE state, int type, int skip)
+static int _gnutls_ssl3_finished(GNUTLS_STATE state, int type, int skip, opaque* ret)
 {
 	int siz;
 	GNUTLS_MAC_HANDLE td;
 	GNUTLS_MAC_HANDLE td2;
 	char tmp[MAX_HASH_SIZE];
-	char *concat;
 	char *mesg, *data;
 
-	concat = gnutls_malloc(36);
-	if (concat==NULL) {
-		gnutls_assert();
-		return NULL;
-	}
-	
 	td = gnutls_mac_init_ssl3_handshake(GNUTLS_MAC_MD5,
 					    state->security_parameters.
 					    master_secret, 48);
+	if (td==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_HASH_FAILED;
+	}
+
 	td2 =
 	    gnutls_mac_init_ssl3_handshake(GNUTLS_MAC_SHA,
 					   state->security_parameters.
 					   master_secret, 48);
+	if (td2==NULL) {
+		gnutls_assert();
+		gnutls_mac_deinit_ssl3_handshake(td, tmp);
+		return GNUTLS_E_HASH_FAILED;
+	}
 
 	siz = gnutls_get_handshake_buffer_size(state) - skip;
 	data = gnutls_malloc(siz);
 	if (data==NULL) {
 		gnutls_assert();
-		return NULL;
+		gnutls_mac_deinit_ssl3_handshake(td2, tmp);
+		gnutls_mac_deinit_ssl3_handshake(td, tmp);
+		return GNUTLS_E_MEMORY_ERROR;
 	}
 
 	gnutls_read_handshake_buffer(state, data, siz);
@@ -160,35 +164,47 @@ void *_gnutls_ssl3_finished(GNUTLS_STATE state, int type, int skip)
 	gnutls_mac_ssl3(td2, mesg, siz);
 
 	gnutls_mac_deinit_ssl3_handshake(td, tmp);
-	memcpy(concat, tmp, 16);
+	memcpy(ret, tmp, 16);
 
 	gnutls_mac_deinit_ssl3_handshake(td2, tmp);
 
-	memcpy(&concat[16], tmp, 20);
-	return concat;
+	memcpy(&ret[16], tmp, 20);
+	return 0;
 }
 
 /* Hash the handshake messages as required by TLS 1.0 */
 #define SERVER_MSG "server finished"
 #define CLIENT_MSG "client finished"
-void *_gnutls_finished(GNUTLS_STATE state, int type, int skip)
+int _gnutls_finished(GNUTLS_STATE state, int type, int skip, void* ret)
 {
 	int siz;
 	GNUTLS_MAC_HANDLE td;
 	GNUTLS_MAC_HANDLE td2;
 	char tmp[MAX_HASH_SIZE];
-	char concat[36];
-	char *mesg;
-	char *data;
+	opaque concat[36];
+	opaque *mesg, *data;
 
 	td = gnutls_hash_init(GNUTLS_MAC_MD5);
+	if (td==GNUTLS_HASH_FAILED) {
+		gnutls_assert();
+		return GNUTLS_E_HASH_FAILED;
+	}
+	
 	td2 = gnutls_hash_init(GNUTLS_MAC_SHA);
+	if (td2==GNUTLS_HASH_FAILED) {
+		gnutls_assert();
+		gnutls_hash_deinit( td2, tmp);
+		return GNUTLS_E_HASH_FAILED;
+	}
 
 	siz = gnutls_get_handshake_buffer_size(state) - skip;
-	data = gnutls_malloc(siz);
+
+	data = gnutls_malloc( siz);
 	if (data==NULL) {
 		gnutls_assert();
-		return NULL;
+		gnutls_hash_deinit( td2, tmp);
+		gnutls_hash_deinit( td, tmp);
+		return GNUTLS_E_MEMORY_ERROR;
 	}
 
 	gnutls_read_handshake_buffer(state, data, siz);
@@ -210,10 +226,8 @@ void *_gnutls_finished(GNUTLS_STATE state, int type, int skip)
 	} else {
 		mesg = CLIENT_MSG;
 	}
-	data =
-	    gnutls_PRF(state->security_parameters.master_secret,
-		       48, mesg, strlen(mesg), concat, 36, 12);
-	return data;
+	return gnutls_PRF(state->security_parameters.master_secret,
+		       48, mesg, strlen(mesg), concat, 36, 12, ret);
 }
 
 /* this function will produce TLS_RANDOM_SIZE bytes of random data
@@ -377,7 +391,7 @@ int _gnutls_read_client_hello(GNUTLS_STATE state, opaque * data,
 					      compression_method,
 					      &data[pos], z);
 #ifdef HANDSHAKE_DEBUG
-	_gnutls_log("Selected Compression Method: %s\n",
+	_gnutls_log("*** Selected Compression Method: %s\n",
 		    gnutls_compression_get_name(state->gnutls_internals.
 						compression_method));
 #endif
@@ -402,28 +416,33 @@ int _gnutls_read_client_hello(GNUTLS_STATE state, opaque * data,
  */
 int _gnutls_send_finished( GNUTLS_STATE state, int again)
 {
-	uint8 *data=NULL;
+	uint8 data[36];
 	int ret;
 	int data_size=0;
 
 	if (again==0) {
 		if (state->security_parameters.version == GNUTLS_SSL3) {
-			data =
+			ret =
 			    _gnutls_ssl3_finished(state,
 						  state->security_parameters.
-						  entity, 0);
+						  entity, 0, data);
 			data_size = 36;
 		} else {		/* TLS 1.0 */
-			data =
+			ret =
 			    _gnutls_finished(state,
-					     state->security_parameters.entity, 0);
+					     state->security_parameters.entity, 0, data);
 			data_size = 12;
 		}
 	}
+
+	if (ret < 0) {
+		gnutls_assert();
+		return ret;
+	}
+	
 	ret =
 	    _gnutls_send_handshake( state, data, data_size,
 				   GNUTLS_FINISHED);
-	gnutls_free(data);
 
 	return ret;
 }
@@ -433,7 +452,7 @@ int _gnutls_send_finished( GNUTLS_STATE state, int again)
  */
 int _gnutls_recv_finished( GNUTLS_STATE state)
 {
-	uint8 *data, *vrfy;
+	uint8 data[36], *vrfy;
 	int data_size;
 	int ret;
 	int vrfysize;
@@ -458,27 +477,32 @@ int _gnutls_recv_finished( GNUTLS_STATE state)
 		gnutls_assert();
 		return GNUTLS_E_ERROR_IN_FINISHED_PACKET;
 	}
+	
 	if (state->security_parameters.version == GNUTLS_SSL3) {
 		/* skip the bytes from the last message */
-		data =
+		ret =
 		    _gnutls_ssl3_finished(state,
 					  (state->security_parameters.
 					   entity + 1) % 2,
 					  vrfysize +
-					  HANDSHAKE_HEADER_SIZE);
+					  HANDSHAKE_HEADER_SIZE, data);
 	} else {		/* TLS 1.0 */
-		data =
+		ret =
 		    _gnutls_finished(state,
 				     (state->security_parameters.entity +
 				      1) % 2,
-				     vrfysize + HANDSHAKE_HEADER_SIZE);
+				     vrfysize + HANDSHAKE_HEADER_SIZE, data);
+	}
+
+	if (ret < 0) {
+		gnutls_assert();
+		return ret;
 	}
 
 	if (memcmp(vrfy, data, data_size) != 0) {
 		gnutls_assert();
 		ret = GNUTLS_E_ERROR_IN_FINISHED_PACKET;
 	}
-	gnutls_free(data);
 	gnutls_free(vrfy);
 
 	return ret;
@@ -496,7 +520,7 @@ static int _gnutls_server_SelectSuite(GNUTLS_STATE state, opaque ret[2],
 	x = _gnutls_supported_ciphersuites(state, &ciphers);
 
 	/* Here we remove any ciphersuite that does not conform
-	 * the certificate requested (using dnsname), or to the
+	 * the certificate requested, or to the
 	 * authentication requested (eg SRP).
 	 */
 	x = _gnutls_remove_unwanted_ciphersuites(state, &ciphers, x);
@@ -519,7 +543,7 @@ static int _gnutls_server_SelectSuite(GNUTLS_STATE state, opaque ret[2],
 			if (memcmp(ciphers[i].CipherSuite, &data[j], 2) ==
 			    0) {
 #ifdef HANDSHAKE_DEBUG
-				_gnutls_log("Selected cipher suite: ");
+				_gnutls_log("*** Selected cipher suite: ");
 				_gnutls_log("%s\n",
 					    _gnutls_cipher_suite_get_name(*
 									  ((GNUTLS_CipherSuite *) & data[j])));
@@ -997,7 +1021,7 @@ static int _gnutls_read_server_hello(GNUTLS_STATE state, char *data,
 	       cipher_suite.CipherSuite, 2);
 
 #ifdef HANDSHAKE_DEBUG
-	_gnutls_log("Selected cipher suite: ");
+	_gnutls_log("Hnadshake: Selected cipher suite: ");
 	_gnutls_log("%s\n",
 		    _gnutls_cipher_suite_get_name(state->
 						  security_parameters.
@@ -1140,12 +1164,24 @@ static int _gnutls_send_client_hello( GNUTLS_STATE state, int again)
 		pos += session_id_len;
 
 		ret = _gnutls_supported_ciphersuites_sorted(state, &cipher_suites);
-		if (ret<0) {
+		if (ret < 0) {
 			gnutls_free(data);
 			gnutls_assert();
 			return ret;
 		}
 
+		/* Here we remove any ciphersuite that does not conform
+		 * the certificate requested, or to the
+		 * authentication requested (eg SRP).
+		 */
+		ret = _gnutls_remove_unwanted_ciphersuites(state, &cipher_suites, ret);
+		if (ret < 0) {
+			gnutls_free(data);
+			gnutls_assert();
+			return ret;
+		}
+
+
 		x = ret;
 		x *= sizeof(uint16);	/* in order to get bytes */
 
@@ -1254,7 +1290,7 @@ static int _gnutls_send_server_hello( GNUTLS_STATE state, int again)
 		pos += session_id_len;
 
 #ifdef HANDSHAKE_DEBUG
-		_gnutls_log("Handshake: SessionID: %s\n",
+		_gnutls_log("*** SessionID: %s\n",
 			    _gnutls_bin2hex(SessionID, session_id_len));
 #endif
 
@@ -1858,8 +1894,7 @@ int _gnutls_recv_hello_request( GNUTLS_STATE state, void *data,
 
 /* This function will remove algorithms that are not supported by
  * the requested authentication method. We only remove algorithm if
- * we receive client hello extensions (dnsname),
- * or if we have a certificate with keyUsage bits set.
+ * we have a certificate with keyUsage bits set.
  */
 int _gnutls_remove_unwanted_ciphersuites(GNUTLS_STATE state,
 					 GNUTLS_CipherSuite **
@@ -1875,11 +1910,6 @@ int _gnutls_remove_unwanted_ciphersuites(GNUTLS_STATE state,
 	int alg_size;
 	KXAlgorithm kx;
 
-	/* ONLY USED IN CASE OF A SERVER.
-	 */
-	 
-	if (state->security_parameters.entity == GNUTLS_CLIENT)
-		return 0;
 
 	/* if we should use a specific certificate, 
 	 * we should remove all algorithms that are not supported
@@ -1895,9 +1925,9 @@ int _gnutls_remove_unwanted_ciphersuites(GNUTLS_STATE state,
 
 	cert = NULL;
 
-	cert =
-	    _gnutls_server_find_cert(state, x509_cred->cert_list,
-						      x509_cred->ncerts);
+	if (state->security_parameters.entity == GNUTLS_SERVER) 
+		cert =
+		    _gnutls_server_find_x509_cert(state);
 
 	if (cert == NULL) {
 		/* No certificate was found 
@@ -1920,33 +1950,63 @@ int _gnutls_remove_unwanted_ciphersuites(GNUTLS_STATE state,
 	    gnutls_malloc(numCipherSuites * sizeof(GNUTLS_CipherSuite));
 	if (newSuite==NULL) {
 		gnutls_assert();
+		gnutls_free(alg);
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 
 	for (i = 0; i < numCipherSuites; i++) {
+		/* finds the key exchange algorithm in
+		 * the ciphersuite
+		 */
 		kx = _gnutls_cipher_suite_get_kx_algo((*cipherSuites)[i]);
 
 		keep = 0;
+
+		/* If there was no credentials to use with the specified
+		 * key exchange method, then just remove it.
+		 */
 		if (_gnutls_map_kx_get_cred(kx) == GNUTLS_X509PKI) {
 			keep = 1;	/* do not keep */
-			if (x509_cred != NULL)
-				for (j = 0; j < alg_size; j++) {
-					if (alg[j] == kx) {
-						keep = 0;
-						break;
+			if (x509_cred != NULL) {
+				if (state->security_parameters.entity == GNUTLS_SERVER) {
+					/* here we check if the KX algorithm 
+					 * is compatible with the X.509 certificate.
+					 */
+					for (j = 0; j < alg_size; j++) {
+						if (alg[j] == kx) {
+							keep = 0;
+							break;
+						}
 					}
-				}
-		} else
-			/* if it is defined but had no credentials 
-			 */
-		    if (_gnutls_get_kx_cred(state->gnutls_key, kx, NULL) ==
-			NULL)
-			keep = 1;
+				} else 	/* CLIENT */ keep = 0;
+			}
+		} else {
 
+		/* if it is defined but had no credentials 
+		 */
+
+		    if (_gnutls_get_kx_cred(state->gnutls_key, kx, NULL) == NULL)
+			keep = 1;
+		}
+				
 		if (keep == 0) {
+#ifdef HANDSHAKE_DEBUG
+			_gnutls_log("*** Keeping ciphersuite: ");
+			_gnutls_log("%s\n",
+					    _gnutls_cipher_suite_get_name(*
+									  ((GNUTLS_CipherSuite *) & (*cipherSuites)[i].CipherSuite)));
+#endif
 			memcpy(newSuite[newSuiteSize].CipherSuite,
 			       (*cipherSuites)[i].CipherSuite, 2);
 			newSuiteSize++;
+#ifdef HANDSHAKE_DEBUG
+		} else {
+			_gnutls_log("*** Removing ciphersuite: ");
+			_gnutls_log("%s\n",
+					    _gnutls_cipher_suite_get_name(*
+									  ((GNUTLS_CipherSuite *) & (*cipherSuites)[i].CipherSuite)));
+
+#endif
 		}
 	}
 
