@@ -20,17 +20,17 @@
 
 typedef enum Optional { OPTIONAL_PACKET, MANDATORY_PACKET } Optional;
 
-int _gnutls_send_handshake(int cd, GNUTLS_STATE state, void* i_data, uint32 i_datasize, HandshakeType type);
-int gnutls_send_hello_request(int cd, GNUTLS_STATE state);
-int _gnutls_recv_hello_request(int cd, GNUTLS_STATE state, void* data, uint32 data_size);
-int _gnutls_send_hello(int cd, GNUTLS_STATE state, int again);
-int _gnutls_recv_hello(int cd, GNUTLS_STATE state, char* data, int datalen);
-int gnutls_handshake(int cd, GNUTLS_STATE state);
-int _gnutls_recv_handshake( int cd, GNUTLS_STATE state, uint8**, int*, HandshakeType, Optional optional);
+int _gnutls_send_handshake( GNUTLS_STATE state, void* i_data, uint32 i_datasize, HandshakeType type);
+int gnutls_send_hello_request( GNUTLS_STATE state);
+int _gnutls_recv_hello_request( GNUTLS_STATE state, void* data, uint32 data_size);
+int _gnutls_send_hello( GNUTLS_STATE state, int again);
+int _gnutls_recv_hello( GNUTLS_STATE state, char* data, int datalen);
+int gnutls_handshake( GNUTLS_STATE state);
+int _gnutls_recv_handshake( GNUTLS_STATE state, uint8**, int*, HandshakeType, Optional optional);
 int _gnutls_generate_session_id( char* session_id, uint8* len);
-int gnutls_handshake_common(int cd, GNUTLS_STATE state);
-int gnutls_handshake_client(int cd, GNUTLS_STATE state);
-int gnutls_handshake_server(int cd, GNUTLS_STATE state);
+int gnutls_handshake_common( GNUTLS_STATE state);
+int gnutls_handshake_client( GNUTLS_STATE state);
+int gnutls_handshake_server( GNUTLS_STATE state);
 void _gnutls_set_server_random( GNUTLS_STATE state, uint8* random);
 void _gnutls_set_client_random( GNUTLS_STATE state, uint8* random);
 int _gnutls_create_random( opaque* dst);
