@@ -84,6 +84,18 @@ void gnutls_transport_set_ptr(GNUTLS_STATE state, GNUTLS_SOCKET_PTR ptr) {
 	state->gnutls_internals.transport_ptr = ptr;
 }
 
+/**
+  * gnutls_transport_get_ptr - Used to return the first argument of the transport functions
+  * @state: is a &GNUTLS_STATE structure.
+  *
+  * Used to get the first argument of the transport function (like PUSH and
+  * PULL). This must have been set using gnutls_transport_set_ptr().
+  *
+  **/
+GNUTLS_SOCKET_PTR gnutls_transport_get_ptr(GNUTLS_STATE state) {
+	return state->gnutls_internals.transport_ptr;
+}
+
 #define _gnutls_free(x) if(x!=NULL) gnutls_free(x)
 /**
   * gnutls_init - This function initializes the state to null (null encryption etc...).
@@ -243,30 +255,23 @@ static void _gnutls_cal_PRF_A( MACAlgorithm algorithm, void *secret, int secret_
 	return;
 }
 
-#define MAX_SEED_SIZE 140
+#define MAX_SEED_SIZE 200
 
 /* Produces "total_bytes" bytes using the hash algorithm specified.
  * (used in the PRF function)
  */
-static svoid *gnutls_P_hash( MACAlgorithm algorithm, opaque * secret, int secret_size, opaque * seed, int seed_size, int total_bytes)
+static int gnutls_P_hash( MACAlgorithm algorithm, opaque * secret, int secret_size, opaque * seed, int seed_size, int total_bytes, opaque* ret)
 {
 
 	GNUTLS_MAC_HANDLE td2;
-	opaque *ret;
 	int i = 0, times, how, blocksize, A_size;
 	opaque final[20], Atmp[MAX_SEED_SIZE];
 
 	if (seed_size > MAX_SEED_SIZE || total_bytes<=0) {
 		gnutls_assert();
-		return NULL;
+		return GNUTLS_E_INTERNAL;
 	}
 	
-	ret = secure_calloc(1, total_bytes);
-	if (ret==NULL) {
-		gnutls_assert();
-		return ret;
-	}
-
 	blocksize = gnutls_hmac_get_algo_len(algorithm);
 	do {
 		i += blocksize;
@@ -300,7 +305,8 @@ static svoid *gnutls_P_hash( MACAlgorithm algorithm, opaque * secret, int secret
 			memcpy(&ret[i * blocksize], final, how);
 		}
 	}
-	return ret;
+	
+	return 0;
 }
 
 /* Function that xor's buffers using the maximum word size supported
@@ -323,22 +329,30 @@ int modlen = _length%sizeof(unsigned long int);
 	return ;
 }
 
+#define MAX_PRF_BYTES 200
+
 /* The PRF function expands a given secret 
- * needed by the TLS specification
+ * needed by the TLS specification. ret must have a least total_bytes
+ * available.
  */
-svoid *gnutls_PRF( opaque * secret, int secret_size, uint8 * label, int label_size, opaque * seed, int seed_size, int total_bytes)
+int gnutls_PRF( opaque * secret, int secret_size, uint8 * label, int label_size, opaque * seed, int seed_size, int total_bytes, void* ret)
 {
 	int l_s, s_seed_size;
-	char *o1, *o2;
 	char *s1, *s2;
-	char *s_seed;
+	opaque s_seed[MAX_SEED_SIZE];
+	opaque o1[MAX_PRF_BYTES], o2[MAX_PRF_BYTES];
+	int result;
 
+	if (total_bytes > MAX_PRF_BYTES) {
+		gnutls_assert();
+		return GNUTLS_E_INTERNAL;
+	}
 	/* label+seed = s_seed */
 	s_seed_size = seed_size + label_size;
-	s_seed = gnutls_malloc(s_seed_size);
-	if (s_seed==NULL) {
+
+	if (s_seed_size > MAX_SEED_SIZE) {
 		gnutls_assert();
-		return NULL;
+		return GNUTLS_E_INTERNAL;
 	}
 
 	memcpy(s_seed, label, label_size);
@@ -352,26 +366,23 @@ svoid *gnutls_PRF( opaque * secret, int secret_size, uint8 * label, int label_si
 		l_s++;
 	}
 
-	o1 = gnutls_P_hash( GNUTLS_MAC_MD5, s1, l_s, s_seed, s_seed_size, total_bytes);
-	if (o1==NULL) {
+	result = gnutls_P_hash( GNUTLS_MAC_MD5, s1, l_s, s_seed, s_seed_size, total_bytes, o1);
+	if (result<0) {
 		gnutls_assert();
-		return NULL;
+		return result;
 	}
 
-	o2 = gnutls_P_hash( GNUTLS_MAC_SHA, s2, l_s, s_seed, s_seed_size, total_bytes);
-	if (o2==NULL) {
+	result = gnutls_P_hash( GNUTLS_MAC_SHA, s2, l_s, s_seed, s_seed_size, total_bytes, o2);
+	if (result<0) {
 		gnutls_assert();
-		return NULL;
+		return result;
 	}
 
-
-	gnutls_free(s_seed);
-
 	_gnutls_xor(o1, o2, total_bytes);
 
-	secure_free(o2);
+	memcpy( ret, o1, total_bytes);
 
-	return o1;
+	return 0; /* ok */
 
 }
 
@@ -476,10 +487,13 @@ int ret = GNUTLS_E_UNIMPLEMENTED_FEATURE;
   * In case of GNUTLS_SHUT_RDWR then the TLS connection gets terminated and
   * further receives and sends will be disallowed. If the return
   * value is zero you may continue using the connection.
+  * (GNUTLS_SHUT_RDWR actually sends an alert containing a close request
+  * and waits for the peer to reply with the same message)
   *
   * In case of GNUTLS_SHUT_WR then the TLS connection gets terminated and
   * further sends will be disallowed. In order to reuse the connection
   * you should wait for an EOF from the peer.
+  * (GNUTLS_SHUT_WR sends an alert containing a close request)
   *
   * This function may also return GNUTLS_E_AGAIN, or GNUTLS_E_INTERRUPTED.
   *
@@ -1193,6 +1207,9 @@ size_t gnutls_get_max_record_size( GNUTLS_STATE state) {
   * get in effect immediately. It will be used after a successful
   * handshake.
   *
+  * This function uses a TLS extension called 'max record size'.
+  * Not all TLS implementations use or even understand this extension.
+  *
   **/
 size_t gnutls_set_max_record_size( GNUTLS_STATE state, size_t size) {
 size_t new_size;
